@@ -1,6 +1,12 @@
 #pragma once
 
 #define PY_SSIZE_T_CLEAN // needed to py310, before python.h
+
+// Undo the damage we're going to cause by undefining a reserved macro name
+#if defined(_MSC_VER) && defined(_DEBUG) && _MSC_VER >= 1930
+#include <corecrt.h>
+#endif
+
 // Hack because debug builds force python36_d.lib
 #ifdef _DEBUG
     #undef _DEBUG
@@ -69,6 +75,13 @@ struct _m256all
     };
 };
 
+// Indicates whether ptr is aligned to the alignment of T.
+template <typename T>
+constexpr bool is_ptr_aligned_as(void const * ptr)
+{
+    return (reinterpret_cast<std::uintptr_t>(ptr) % std::alignment_of_v<T>) == 0;
+}
+
 static const int NUMPY_LAST_TYPE = 24;
 static const int MAX_NUMPY_TYPE = 24;
 
