@@ -1,6 +1,11 @@
 #ifndef RIPTIDE_PYTHON_TEST_H
 #define RIPTIDE_PYTHON_TEST_H
 
+// Undo the damage we're about to do by undefining a reserved macro name
+#if defined(_MSC_VER) && defined(_DEBUG) && _MSC_VER >= 1930
+#include <corecrt.h>
+#endif
+
 #ifdef _DEBUG
 #undef _DEBUG
 #include "Python.h"
@@ -11,7 +16,8 @@
 
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 
-#define PY_ARRAY_UNIQUE_SYMBOL riptide_python_test_global
+//#define PY_ARRAY_UNIQUE_SYMBOL riptide_python_test_global
+#define PY_ARRAY_UNIQUE_SYMBOL sharedata_ARRAY_API
 #ifndef PYTHON_TEST_MAIN
 #define NO_IMPORT_ARRAY (1)
 #else
